@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2014-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -56,7 +56,7 @@ void ServerSieveSettingsTest::shouldEmitEnableOkButtonSignal()
 {
     ServerSieveSettings widget;
     widget.show();
-    QTest::qWaitForWindowExposed(&widget);
+    QVERIFY(QTest::qWaitForWindowExposed(&widget));
     QSignalSpy spy(&widget, SIGNAL(enableOkButton(bool)));
     widget.setPassword(QStringLiteral("foo"));
     QCOMPARE(spy.count(), 0);
@@ -79,7 +79,7 @@ void ServerSieveSettingsTest::shouldEmitSignalWithValueTrue()
 {
     ServerSieveSettings widget;
     widget.show();
-    QTest::qWaitForWindowExposed(&widget);
+    QVERIFY(QTest::qWaitForWindowExposed(&widget));
     QSignalSpy spy(&widget, SIGNAL(enableOkButton(bool)));
     widget.setServerName(QStringLiteral("foo"));
     QCOMPARE(spy.count(), 1);
